# Generated by Django 3.2.4 on 2021-07-30 05:12

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="FailedSignInAttempt",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("device_ip", models.GenericIPAddressField(blank=True, db_index=True, null=True, unpack_ipv4=True)),
                ("attempt_date", models.DateField(default=django.utils.timezone.now)),
                ("attempt_count", models.IntegerField(default=1)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="PasswordResetLog",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("type", models.CharField(choices=[("Reset", 1), ("Change", 2)], default=2, max_length=10)),
                ("request_ip", models.GenericIPAddressField(blank=True, db_index=True, null=True, unpack_ipv4=True)),
                ("change_ip", models.GenericIPAddressField(blank=True, db_index=True, null=True, unpack_ipv4=True)),
                ("request_time", models.DateTimeField(default=django.utils.timezone.now)),
                ("change_time", models.DateTimeField(null=True)),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
